fn has_peer_conflict(region_route: &RegionRoute, to_peer_id: u64) -> boolExpand description
Returns true if to_peer is already a follower of the region (conflict).
fn has_peer_conflict(region_route: &RegionRoute, to_peer_id: u64) -> boolReturns true if to_peer is already a follower of the region (conflict).